@@ -1,9 +1,9 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2009, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     For this file, the following copyright notice is also applicable:
-    Copyright (C) 2005-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+    Copyright (C) 2005-2010, rncbc aka Rui Nuno Capela. All rights reserved.
     See http://qtractor.sourceforge.net
 
     This program is free software; you can redistribute it and/or modify
@@ -26,8 +26,8 @@
 #ifndef __instrument_h
 #define __instrument_h
 
-#include <QStringList>
-#include <QMap>
+#include <QtCore/QStringList>
+#include <QtCore/QMap>
 
 // Forward declarations.
 class QTextStream;
@@ -81,8 +81,8 @@ public:
 	Iterator end()   { return m_pData->map.end(); }
 
 	typedef DataMap::ConstIterator ConstIterator;
-	ConstIterator begin() const { return m_pData->map.constBegin(); }
-	ConstIterator end()   const { return m_pData->map.constEnd(); }
+	ConstIterator constBegin() const { return m_pData->map.constBegin(); }
+	ConstIterator constEnd()   const { return m_pData->map.constEnd(); }
 
 	unsigned int count() const { return m_pData->map.count(); }
 
