@@ -1,6 +1,6 @@
 /*
     Virtual Piano Widget for Qt4
-    Copyright (C) 2008-2009, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,18 @@
     with this program; If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QFont>
 #include "keylabel.h"
+#include "pianokey.h"
+#include <QtGui/QFont>
 
 KeyLabel::KeyLabel(QGraphicsItem *parent) : QGraphicsTextItem(parent)
 {
     setAcceptedMouseButtons(Qt::NoButton);
     rotate(270);
 }
+
+QRectF KeyLabel::boundingRect() const
+{
+    PianoKey* key = static_cast<PianoKey*>(parentItem());
+    return mapRectFromScene(key->rect());
+}
