@@ -1,6 +1,6 @@
 /*
     Virtual Piano Widget for Qt4
-    Copyright (C) 2008-2009, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,13 +20,14 @@
 #define KEYLABEL_H
 
 #include "pianodefs.h"
-#include <QGraphicsTextItem>
+#include <QtGui/QGraphicsTextItem>
 
 class VPIANO_EXPORT KeyLabel : public QGraphicsTextItem
 {
 public:
     KeyLabel(QGraphicsItem *parent = 0);
     virtual ~KeyLabel() {}
+    virtual QRectF boundingRect() const;
 };
 
 #endif // KEYLABEL_H
