@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2009, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 #ifndef KMAPDIALOG_H
 #define KMAPDIALOG_H
 
-#include <QDialog>
 #include "ui_kmapdialog.h"
 #include "keyboardmap.h"
+#include <QtGui/QDialog>
 
 class KMapDialog : public QDialog
 {
