@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2009, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,8 +19,8 @@
 #ifndef MIDISETUP_H
 #define MIDISETUP_H
 
-#include <QDialog>
 #include "ui_midisetup.h"
+#include <QtGui/QDialog>
 
 class MidiSetup : public QDialog
 {
