@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2009, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,18 +20,18 @@
 #include "constants.h"
 #include "vpiano.h"
 
-#include <QPushButton>
-#include <QShowEvent>
-#include <QFileDialog>
-#include <QColorDialog>
+#include <QtGui/QPushButton>
+#include <QtGui/QShowEvent>
+#include <QtGui/QFileDialog>
+#include <QtGui/QColorDialog>
 
 Preferences::Preferences(QWidget *parent)
     : QDialog(parent),
     m_numOctaves(5),
+    m_drumsChannel(MIDIGMDRUMSCHANNEL),
     m_grabKb(false),
     m_styledKnobs(true),
     m_alwaysOnTop(false),
-    m_showLabels(false),
     m_rawKeyboard(false)
 {
     ui.setupUi( this );
@@ -53,10 +53,10 @@ void Preferences::showEvent ( QShowEvent *event )
 {
     if (event->type() == QEvent::Show) {
         ui.spinNumOctaves->setValue( m_numOctaves );
+        ui.cboDrumsChannel->setCurrentIndex(m_drumsChannel+1);
         ui.chkGrabKb->setChecked( m_grabKb );
         ui.chkStyledKnobs->setChecked( m_styledKnobs );
         ui.chkAlwaysOnTop->setChecked( m_alwaysOnTop );
-        ui.chkShowNames->setChecked( m_showLabels );
         ui.chkRawKeyboard->setChecked( m_rawKeyboard );
         if (!m_keyPressedColor.isValid()) {
             setKeyPressedColor(QApplication::palette().highlight().color());
@@ -71,7 +71,6 @@ void Preferences::apply()
     m_grabKb = ui.chkGrabKb->isChecked();
     m_styledKnobs = ui.chkStyledKnobs->isChecked();
     m_alwaysOnTop = ui.chkAlwaysOnTop->isChecked();
-    m_showLabels = ui.chkShowNames->isChecked();
     m_rawKeyboard = ui.chkRawKeyboard->isChecked();
     if ( ui.txtFileRawKmap->text().isEmpty() ||
          ui.txtFileRawKmap->text() == QSTR_DEFAULT)
@@ -82,6 +81,7 @@ void Preferences::apply()
     if ( ui.txtFileInstrument->text().isEmpty() ||
          ui.txtFileInstrument->text() == QSTR_DEFAULT )
         m_insFileName = QSTR_DEFAULT;
+    m_drumsChannel = ui.cboDrumsChannel->currentIndex() - 1;
 }
 
 void Preferences::accept()
@@ -112,6 +112,19 @@ Instrument* Preferences::getInstrument()
     QString key = ui.cboInstrument->currentText();
     if (key.isEmpty())
         return NULL;
+    if (!m_ins.contains(key))
+        return NULL;
+    return &m_ins[key];
+}
+
+Instrument* Preferences::getDrumsInstrument()
+{
+    QString key = ui.cboInstrument->currentText();
+    if (key.isEmpty())
+        return NULL;
+    key.append(" Drums");
+    if (!m_ins.contains(key))
+        return NULL;
     return &m_ins[key];
 }
 
@@ -124,8 +137,9 @@ void Preferences::setInstrumentsFileName( const QString fileName )
         if (m_ins.load(fileName)) {
             ui.txtFileInstrument->setText(f.fileName());
             InstrumentList::ConstIterator it;
-            for(it = m_ins.begin(); it != m_ins.end(); ++it) {
-                ui.cboInstrument->addItem(it.key());
+            for(it = m_ins.constBegin(); it != m_ins.constEnd(); ++it) {
+                if(!it.key().endsWith(QLatin1String("Drums"), Qt::CaseInsensitive))
+                    ui.cboInstrument->addItem(it.key());
             }
             ui.cboInstrument->setCurrentIndex(-1);
             m_insFileName = fileName;
@@ -213,7 +227,6 @@ void Preferences::restoreDefaults()
     ui.chkAlwaysOnTop->setChecked(false);
     ui.chkGrabKb->setChecked(false);
     ui.chkRawKeyboard->setChecked(false);
-    ui.chkShowNames->setChecked(false);
     ui.chkStyledKnobs->setChecked(true);
     ui.spinNumOctaves->setValue(5);
     ui.txtFileKmap->setText(QSTR_DEFAULT);
