@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2009, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,11 @@
     with this program; If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QFileInfo>
-#include <QFile>
-#include <QTextStream>
-#include <QFileDialog>
-#include <QDesktopServices>
+#include <QtCore/QFileInfo>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtGui/QFileDialog>
+#include <QtGui/QDesktopServices>
 
 #include "riffimportdlg.h"
 #include "ui_riffimportdlg.h"
