@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2009, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,11 +19,9 @@
 #ifndef VPIANO_H
 #define VPIANO_H
 
-#include <QMainWindow>
-#include <QEvent>
-
 #include "ui_vpiano.h"
-#include "mididefs.h"
+#include "pianoscene.h"
+#include <QtGui/QMainWindow>
 
 class QComboBox;
 class QSpinBox;
@@ -40,66 +38,10 @@ class KMapDialog;
 class DialogExtraControls;
 class RiffImportDlg;
 
-const QEvent::Type NoteOnEventType = QEvent::Type( QEvent::registerEventType( QEvent::User + STATUS_NOTEON ));
-const QEvent::Type NoteOffEventType = QEvent::Type( QEvent::registerEventType( QEvent::User + STATUS_NOTEOFF ));
-const QEvent::Type ControllerEventType = QEvent::Type( QEvent::registerEventType( QEvent::User + STATUS_CONTROLLER ));
-const QEvent::Type BenderEventType = QEvent::Type( QEvent::registerEventType( QEvent::User + STATUS_BENDER));
-
-class NoteEvent : public QEvent
-{
-public:
-    NoteEvent(unsigned char note, QEvent::Type type)
-        : QEvent(type),
-        m_note(note) { }
-    unsigned char getNote() const { return m_note; }
-private:
-    unsigned char m_note;
-};
-
-class NoteOnEvent : public NoteEvent
-{
-public:
-    NoteOnEvent(unsigned char note)
-        : NoteEvent(note, NoteOnEventType)
-    { }
-};
-
-class NoteOffEvent : public NoteEvent
-{
-public:
-    NoteOffEvent(unsigned char note)
-        : NoteEvent(note, NoteOffEventType)
-    { }
-};
-
-class ControllerEvent : public QEvent
-{
-public:
-    ControllerEvent(unsigned char ctl, unsigned char val)
-        : QEvent(ControllerEventType),
-        m_ctl(ctl),
-        m_value(val)
-        { }
-    unsigned char getController() const { return m_ctl; }
-    unsigned char getValue() const { return m_value; }
-private:
-    unsigned char m_ctl;
-    unsigned char m_value;
-};
-
-class BenderEvent : public QEvent
-{
-public:
-    BenderEvent(int value) : QEvent(BenderEventType), m_value(value)
-    { }
-    int getValue() const { return m_value; }
-private:
-    int m_value;
-};
-
 class VPiano : public QMainWindow, public PianoHandler
 {
     Q_OBJECT
+
 public:
     VPiano( QWidget * parent = 0, Qt::WindowFlags flags = 0 );
     virtual ~VPiano();
@@ -114,13 +56,41 @@ public:
     // static methods
     static QString dataDirectory();
 
-protected:
-    void closeEvent ( QCloseEvent *event );
-    void customEvent ( QEvent *event );
-    void showEvent ( QShowEvent *event );
-    void hideEvent( QHideEvent *event );
+#if ENABLE_DBUS
 
-public slots:
+public Q_SLOTS:
+    void quit();
+    void panic();
+    void reset_controllers();
+    void channel(int value);
+    void octave(int value);
+    void transpose(int value);
+    void velocity(int value);
+    void connect_in(const QString &value);
+    void connect_out(const QString &value);
+    void connect_thru(bool value);
+
+    void noteoff(int note);
+    void noteon(int note);
+    void polykeypress(int note, int value);
+    void controlchange(int control, int value);
+    void programchange(int value);
+    void programnamechange(const QString &value);
+    void chankeypress(int value);
+    void pitchwheel(int value);
+
+Q_SIGNALS:
+    void event_noteoff(int note);
+    void event_noteon(int note);
+    void event_polykeypress(int note, int value);
+    void event_controlchange(int control, int value);
+    void event_programchange(int value);
+    void event_chankeypress(int value);
+    void event_pitchwheel(int value);
+
+#endif /*ENABLE_DBUS*/
+
+protected Q_SLOTS:
     void slotAbout();
     void slotAboutQt();
     void slotConnections();
@@ -129,57 +99,77 @@ public slots:
     void slotPanic();
     void slotResetAllControllers();
     void slotResetBender();
-    void slotController(const int value);
-    void slotExtraController(const int value);
-    void slotControlClicked(const bool value);
-    void slotBender(const int pos);
-    void slotBenderReleased();
-    void slotBankChanged(const int index);
-    void slotProgChanged(const int index);
-    void slotBaseOctave(const int octave);
-    void slotTranspose(const int transpose);
-    void slotOutChannel(const int channel);
-    void slotCtlChanged(const int index);
     void slotHelpContents();
     void slotOpenWebSite();
-    void setVelocity(int value);
     void slotImportSF();
     void slotEditExtraControls();
+    void slotShowNoteNames();
+    void slotControlSliderMoved(const int value);
+    void slotExtraController(const int value);
+    void slotControlClicked(const bool value);
+    void slotBenderSliderMoved(const int pos);
+    void slotBenderSliderReleased();
+    void slotComboBankActivated(const int index = -1);
+    void slotComboProgActivated(const int index = -1);
+    void slotBaseOctaveValueChanged(const int octave);
+    void slotTransposeValueChanged(const int transpose);
+    void slotVelocityValueChanged(int value);
+    void slotChannelValueChanged(const int channel);
+    void slotComboControlCurrentIndexChanged(const int index);
     //void slotEditPrograms();
     //void slotDebugDestroyed(QObject *obj);
 
+protected:
+    void closeEvent ( QCloseEvent *event );
+    void customEvent ( QEvent *event );
+    void showEvent ( QShowEvent *event );
+    void hideEvent( QHideEvent *event );
+
 private:
     void initialization();
     bool initMidi();
-    void initControllers();
     void readSettings();
     void writeSettings();
     void applyPreferences();
     void applyConnections();
     void applyInitialSettings();
+    void populateControllers();
+    void populateInstruments();
+    void populatePrograms(int bank = -1);
     void refreshConnections();
     void initToolBars();
     void clearExtraControllers();
     void initExtraControllers();
-    void sendController(const int controller, const int value);
+    void initControllers(int channel);
     void resetAllControllers();
     void allNotesOff();
-    void bankChange(const int bank);
-    void programChange(const int program);
-    void bender(const int value);
-    void messageWrapper(std::vector<unsigned char> *message) const;
+    void sendController(const int controller, const int value);
+    void sendBankChange(const int bank);
+    void sendNoteOn(const int midiNote);
+    void sendNoteOff(const int midiNote);
+    void sendProgramChange(const int program);
+    void sendBender(const int value);
+    void sendPolyKeyPress(const int note, const int value);
+    void sendChanKeyPress(const int value);
+    void sendSysex(const QByteArray& data);
+    void sendMessageWrapper(std::vector<unsigned char> *message) const;
     void updateController(int ctl, int val);
     void updateExtraController(int ctl, int val);
+    void updateBankChange(int bank = -1);
+    void updateProgramChange(int program = -1);
     void grabKb();
     void releaseKb();
     void updateStyles();
+    void updateNoteNames(bool drums);
     void setWidgetTip(QWidget* w, int val);
+    QByteArray readSysexDataFile(const QString& fileName);
+
     About *dlgAbout();
     Preferences *dlgPreferences();
     MidiSetup *dlgMidiSetup();
     KMapDialog *dlgKeyMap();
     DialogExtraControls *dlgExtra();
-   RiffImportDlg *dlgRiffImport();
+    RiffImportDlg *dlgRiffImport();
 
     RtMidiOut* m_midiout;
     RtMidiIn* m_midiin;
@@ -209,11 +199,11 @@ private:
     QComboBox* m_comboProg;
     QStyle* m_dialStyle;
     Instrument* m_ins;
-    QMap<int,int> m_ctlState, m_ctlSettings;
     QStringList m_extraControls;
-    int m_lastBank;
-    int m_lastProg;
-    int m_lastCtl;
+    QMap<int,QMap<int,int> > m_ctlState, m_ctlSettings;
+    QMap<int,int> m_lastBank;
+    QMap<int,int> m_lastProg;
+    QMap<int,int> m_lastCtl;
     int m_channel;
     int m_velocity;
     int m_baseOctave;
