@@ -63,10 +63,20 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>DialogExtraControls</name>
     <message>
-        <location filename="../src/extracontrols.cpp" line="66"/>
+        <location filename="../src/extracontrols.cpp" line="69"/>
         <source>New Control</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/extracontrols.cpp" line="234"/>
+        <source>System Exclusive File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/extracontrols.cpp" line="234"/>
+        <source>System Exclusive (*.syx)</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/extracontrols.ui" line="14"/>
         <source>Extra Controls Editor</source>
@@ -123,46 +133,71 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/extracontrols.ui" line="185"/>
+        <location filename="../src/extracontrols.ui" line="166"/>
+        <source>Button Ctl</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/extracontrols.ui" line="171"/>
+        <source>Button SysEx</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/extracontrols.ui" line="195"/>
         <source>Default ON</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/extracontrols.ui" line="192"/>
+        <location filename="../src/extracontrols.ui" line="202"/>
         <source>value ON:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/extracontrols.ui" line="209"/>
+        <location filename="../src/extracontrols.ui" line="219"/>
         <source>value OFF:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/extracontrols.ui" line="230"/>
-        <location filename="../src/extracontrols.ui" line="285"/>
-        <location filename="../src/extracontrols.ui" line="357"/>
+        <location filename="../src/extracontrols.ui" line="240"/>
+        <location filename="../src/extracontrols.ui" line="295"/>
+        <location filename="../src/extracontrols.ui" line="367"/>
         <source>Min. value:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/extracontrols.ui" line="247"/>
-        <location filename="../src/extracontrols.ui" line="302"/>
-        <location filename="../src/extracontrols.ui" line="374"/>
+        <location filename="../src/extracontrols.ui" line="257"/>
+        <location filename="../src/extracontrols.ui" line="312"/>
+        <location filename="../src/extracontrols.ui" line="384"/>
         <source>Max. value:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/extracontrols.ui" line="264"/>
-        <location filename="../src/extracontrols.ui" line="319"/>
-        <location filename="../src/extracontrols.ui" line="391"/>
+        <location filename="../src/extracontrols.ui" line="274"/>
+        <location filename="../src/extracontrols.ui" line="329"/>
+        <location filename="../src/extracontrols.ui" line="401"/>
         <source>Default value:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/extracontrols.ui" line="340"/>
+        <location filename="../src/extracontrols.ui" line="350"/>
         <source>Display size:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/extracontrols.ui" line="422"/>
+        <source>value:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/extracontrols.ui" line="456"/>
+        <source>File name:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/extracontrols.ui" line="473"/>
+        <source>...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>KMapDialog</name>
@@ -187,28 +222,28 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished">Klayve Düzeni Düzenleyici</translation>
     </message>
     <message>
-        <location filename="../src/kmapdialog.cpp" line="44"/>
+        <location filename="../src/kmapdialog.cpp" line="45"/>
         <source>Key Code</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/kmapdialog.cpp" line="44"/>
+        <location filename="../src/kmapdialog.cpp" line="45"/>
         <source>Key</source>
         <translation type="unfinished">Tuş</translation>
     </message>
     <message>
-        <location filename="../src/kmapdialog.cpp" line="87"/>
+        <location filename="../src/kmapdialog.cpp" line="88"/>
         <source>Open keyboard map definition</source>
         <translation type="unfinished">Klavye düzeni tanımlaması aç</translation>
     </message>
     <message>
-        <location filename="../src/kmapdialog.cpp" line="89"/>
-        <location filename="../src/kmapdialog.cpp" line="102"/>
+        <location filename="../src/kmapdialog.cpp" line="90"/>
+        <location filename="../src/kmapdialog.cpp" line="103"/>
         <source>Keyboard map (*.xml)</source>
         <translation type="unfinished">Klavye düzeni (*.xml)</translation>
     </message>
     <message>
-        <location filename="../src/kmapdialog.cpp" line="100"/>
+        <location filename="../src/kmapdialog.cpp" line="101"/>
         <source>Save keyboard map definition</source>
         <translation type="unfinished">Klavye düzeni tanımlamasını kaydet</translation>
     </message>
@@ -216,7 +251,7 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>KMapDialogClass</name>
     <message>
-        <location filename="../src/kmapdialog.ui" line="17"/>
+        <location filename="../src/kmapdialog.ui" line="14"/>
         <source>Key Map Editor</source>
         <translation>Klayve Düzeni Düzenleyici</translation>
     </message>
@@ -866,7 +901,7 @@ p, li { white-space: pre-wrap; }
         <translation>Tuş</translation>
     </message>
     <message>
-        <location filename="../src/kmapdialog.ui" line="33"/>
+        <location filename="../src/kmapdialog.ui" line="27"/>
         <source>This box displays the name of the current mapping file</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1057,14 +1092,14 @@ p, li { white-space: pre-wrap; }
         <translation>Enstrüman tanımlaması (*.ins)</translation>
     </message>
     <message>
-        <location filename="../src/preferences.cpp" line="168"/>
-        <location filename="../src/preferences.cpp" line="179"/>
+        <location filename="../src/preferences.cpp" line="182"/>
+        <location filename="../src/preferences.cpp" line="193"/>
         <source>Open keyboard map definition</source>
         <translation type="unfinished">Klavye düzeni tanımlaması aç</translation>
     </message>
     <message>
-        <location filename="../src/preferences.cpp" line="170"/>
-        <location filename="../src/preferences.cpp" line="181"/>
+        <location filename="../src/preferences.cpp" line="184"/>
+        <location filename="../src/preferences.cpp" line="195"/>
         <source>Keyboard map (*.xml)</source>
         <translation type="unfinished">Klavye düzeni (*.xml)</translation>
     </message>
@@ -1113,17 +1148,17 @@ p, li { white-space: pre-wrap; }
         <translation>Enstrüman dosyası</translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="119"/>
+        <location filename="../src/preferences.ui" line="122"/>
         <source>default</source>
         <translation>öntanımlı</translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="132"/>
+        <location filename="../src/preferences.ui" line="135"/>
         <source>load...</source>
         <translation>yükle...</translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="145"/>
+        <location filename="../src/preferences.ui" line="148"/>
         <source>Instrument</source>
         <translation>Enstrüman</translation>
     </message>
@@ -1147,48 +1182,48 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="116"/>
+        <location filename="../src/preferences.ui" line="119"/>
         <source>The instruments definition file currently loaded</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="129"/>
+        <location filename="../src/preferences.ui" line="132"/>
         <source>Press this button to load an instruments definition file from disk.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="164"/>
+        <location filename="../src/preferences.ui" line="170"/>
         <source>Change the instrument definition being currently used. Each instruments definition file may hold several instruments on it.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="171"/>
+        <location filename="../src/preferences.ui" line="177"/>
         <source>Keyboard Map</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="181"/>
-        <location filename="../src/preferences.ui" line="198"/>
+        <location filename="../src/preferences.ui" line="190"/>
+        <location filename="../src/preferences.ui" line="210"/>
         <source>Load...</source>
         <translation type="unfinished">Yükle...</translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="188"/>
+        <location filename="../src/preferences.ui" line="197"/>
         <source>Raw Keyboard Map</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="205"/>
+        <location filename="../src/preferences.ui" line="217"/>
         <source>Change the widget (knobs, switches) style, either using the custom look or reverting to the style selected in qtconfig.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="208"/>
+        <location filename="../src/preferences.ui" line="220"/>
         <source>Styled Widgets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="242"/>
+        <location filename="../src/preferences.ui" line="254"/>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -1200,17 +1235,102 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="218"/>
+        <location filename="../src/preferences.ui" line="278"/>
+        <source>Drums Channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="289"/>
+        <source>None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="294"/>
+        <source>1</source>
+        <translation type="unfinished">1</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="299"/>
+        <source>2</source>
+        <translation type="unfinished">2</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="304"/>
+        <source>3</source>
+        <translation type="unfinished">3</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="309"/>
+        <source>4</source>
+        <translation type="unfinished">4</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="314"/>
+        <source>5</source>
+        <translation type="unfinished">5</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="319"/>
+        <source>6</source>
+        <translation type="unfinished">6</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="324"/>
+        <source>7</source>
+        <translation type="unfinished">7</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="329"/>
+        <source>8</source>
+        <translation type="unfinished">8</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="334"/>
+        <source>9</source>
+        <translation type="unfinished">9</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="339"/>
+        <source>10</source>
+        <translation type="unfinished">10</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="344"/>
+        <source>11</source>
+        <translation type="unfinished">11</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="349"/>
+        <source>12</source>
+        <translation type="unfinished">12</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="354"/>
+        <source>13</source>
+        <translation type="unfinished">13</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="359"/>
+        <source>14</source>
+        <translation type="unfinished">14</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="364"/>
+        <source>15</source>
+        <translation type="unfinished">15</translation>
+    </message>
+    <message>
+        <location filename="../src/preferences.ui" line="230"/>
         <source>Check this box to keep the keyboard window always visible, on top of other windows.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="221"/>
+        <location filename="../src/preferences.ui" line="233"/>
         <source>Always On Top</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="228"/>
+        <location filename="../src/preferences.ui" line="240"/>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -1219,25 +1339,15 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="235"/>
+        <location filename="../src/preferences.ui" line="247"/>
         <source>Grab Computer Keyboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/preferences.ui" line="252"/>
+        <location filename="../src/preferences.ui" line="264"/>
         <source>Raw Computer Keyboard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../src/preferences.ui" line="259"/>
-        <source>Check this box to display the note names over the piano keys.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/preferences.ui" line="262"/>
-        <source>Show Note Names</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -1339,63 +1449,63 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>VPiano</name>
     <message>
-        <location filename="../src/vpiano.cpp" line="162"/>
-        <location filename="../src/vpiano.cpp" line="1228"/>
+        <location filename="../src/vpiano.cpp" line="165"/>
+        <location filename="../src/vpiano.cpp" line="1364"/>
         <source>Error</source>
         <translation>Hata</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="163"/>
+        <location filename="../src/vpiano.cpp" line="166"/>
         <source>No MIDI output ports available. Aborting</source>
         <translation>Hiç MIDI çıktı portu yok. Çıkılıyor</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="186"/>
+        <location filename="../src/vpiano.cpp" line="189"/>
         <source>Error. Aborting</source>
         <translation>Hata. Çıkılıyor</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="199"/>
+        <location filename="../src/vpiano.cpp" line="202"/>
         <source>Channel:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="207"/>
+        <location filename="../src/vpiano.cpp" line="210"/>
         <source>Base Octave:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="215"/>
+        <location filename="../src/vpiano.cpp" line="218"/>
         <source>Transpose:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="223"/>
+        <location filename="../src/vpiano.cpp" line="226"/>
         <source>Velocity:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="245"/>
+        <location filename="../src/vpiano.cpp" line="248"/>
         <source>Control:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="251"/>
+        <location filename="../src/vpiano.cpp" line="254"/>
         <source>Value:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="267"/>
+        <location filename="../src/vpiano.cpp" line="270"/>
         <source>Bender:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="281"/>
+        <location filename="../src/vpiano.cpp" line="284"/>
         <source>Bank:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="287"/>
+        <location filename="../src/vpiano.cpp" line="290"/>
         <source>Program:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1436,9 +1546,8 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Klavye düzeni tanımlamasını kaydet</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="14"/>
         <source>Virtual Piano Keyboard</source>
-        <translation>Sanal Piyano Klavyesi</translation>
+        <translation type="obsolete">Sanal Piyano Klavyesi</translation>
     </message>
     <message>
         <location filename="../src/vpiano.ui" line="37"/>
@@ -1465,162 +1574,167 @@ p, li { white-space: pre-wrap; }
         <translation>&amp;Görünüm</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="92"/>
-        <location filename="../src/vpiano.ui" line="238"/>
+        <location filename="../src/vpiano.ui" line="93"/>
+        <location filename="../src/vpiano.ui" line="239"/>
         <source>&amp;Notes</source>
         <translation>&amp;Notalar</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="114"/>
-        <location filename="../src/vpiano.ui" line="249"/>
+        <location filename="../src/vpiano.ui" line="115"/>
+        <location filename="../src/vpiano.ui" line="250"/>
         <source>&amp;Controllers</source>
         <translation>&amp;Denetleyiciler</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="136"/>
-        <location filename="../src/vpiano.ui" line="260"/>
+        <location filename="../src/vpiano.ui" line="137"/>
+        <location filename="../src/vpiano.ui" line="261"/>
         <source>Pitch &amp;Bender</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="158"/>
-        <location filename="../src/vpiano.ui" line="271"/>
+        <location filename="../src/vpiano.ui" line="159"/>
+        <location filename="../src/vpiano.ui" line="272"/>
         <source>&amp;Programs</source>
         <translation>&amp;Programlar</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="179"/>
-        <location filename="../src/vpiano.ui" line="346"/>
+        <location filename="../src/vpiano.ui" line="180"/>
+        <location filename="../src/vpiano.ui" line="347"/>
         <source>&amp;Extra Controls</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="195"/>
+        <location filename="../src/vpiano.ui" line="196"/>
         <source>&amp;Quit</source>
         <translation>&amp;Çık</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="198"/>
+        <location filename="../src/vpiano.ui" line="199"/>
         <source>Exit the program</source>
         <translation>Uygulamadan çık</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="203"/>
+        <location filename="../src/vpiano.ui" line="204"/>
         <source>&amp;Preferences</source>
         <translation>&amp;Tercihler</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="206"/>
+        <location filename="../src/vpiano.ui" line="207"/>
         <source>Edit the program settings</source>
         <translation>Uygulamala ayarlarını düzenle</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="211"/>
+        <location filename="../src/vpiano.ui" line="212"/>
         <source>&amp;Connections</source>
         <translation>&amp;Bağlantılar</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="214"/>
+        <location filename="../src/vpiano.ui" line="215"/>
         <source>Edit the MIDI connections</source>
         <translation>MIDI bağlantılarını düzenle</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="219"/>
+        <location filename="../src/vpiano.ui" line="220"/>
         <source>&amp;About</source>
         <translation>&amp;Hakkında</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="222"/>
+        <location filename="../src/vpiano.ui" line="223"/>
         <source>Show the About box</source>
         <translation>Hakkında Penceresini Göster</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="227"/>
+        <location filename="../src/vpiano.ui" line="228"/>
         <source>About Q&amp;t</source>
         <translation>Q&amp;t Hakkında</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="230"/>
+        <location filename="../src/vpiano.ui" line="231"/>
         <source>Show the Qt about box</source>
         <translation>Qt Hakkında Penceresini Göster</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="241"/>
+        <location filename="../src/vpiano.ui" line="242"/>
         <source>Show or hide the Notes toolbar</source>
         <translation>Nota araç çubuğunu göster veya gizle</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="252"/>
+        <location filename="../src/vpiano.ui" line="253"/>
         <source>Show or hide the Controller toolbar</source>
         <translation>Denetleyici araç çubuğunu göster veya gizle</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="263"/>
+        <location filename="../src/vpiano.ui" line="264"/>
         <source>Show or hide the Pitch Bender toolbar</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="274"/>
+        <location filename="../src/vpiano.ui" line="275"/>
         <source>Show or hide the Programs toolbar</source>
         <translation>Programlar araç çubuğunu göster veya gizle</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="285"/>
+        <location filename="../src/vpiano.ui" line="286"/>
         <source>&amp;Status Bar</source>
         <translation>&amp;Durum Çubuğu</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="290"/>
+        <location filename="../src/vpiano.ui" line="291"/>
         <source>Panic</source>
         <translation>Panik</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="293"/>
+        <location filename="../src/vpiano.ui" line="294"/>
         <source>Stops all active notes</source>
         <translation>Tüm etkin notaları durdur</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="298"/>
+        <location filename="../src/vpiano.ui" line="299"/>
         <source>Reset All</source>
         <translation>Tümünü Sıfırla</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="301"/>
+        <location filename="../src/vpiano.ui" line="302"/>
         <source>Resets all the controllers</source>
         <translation>Tüm denetleyicileri sıfırla</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="306"/>
+        <location filename="../src/vpiano.ui" line="307"/>
         <source>Reset</source>
         <translation>Sıfırla</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="309"/>
+        <location filename="../src/vpiano.ui" line="310"/>
         <source>Resets the Bender value</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="351"/>
-        <location filename="../src/vpiano.ui" line="362"/>
+        <location filename="../src/vpiano.ui" line="352"/>
+        <location filename="../src/vpiano.ui" line="363"/>
         <source>Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="354"/>
-        <location filename="../src/vpiano.ui" line="379"/>
+        <location filename="../src/vpiano.ui" line="355"/>
+        <location filename="../src/vpiano.ui" line="380"/>
         <source>Open the Extra Controls editor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="365"/>
+        <location filename="../src/vpiano.ui" line="366"/>
         <source>Open the Banks/Programs editor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="376"/>
+        <location filename="../src/vpiano.ui" line="377"/>
         <source>&amp;Extra Controllers</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/vpiano.ui" line="388"/>
+        <source>N&amp;ote Names</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Load...</source>
         <translation type="obsolete">Yükle...</translation>
@@ -1638,7 +1752,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Geçerli klavye düzenini kaydet</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="314"/>
+        <location filename="../src/vpiano.ui" line="315"/>
         <source>&amp;Keyboard Map</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1647,37 +1761,37 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Düzenle...</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="317"/>
+        <location filename="../src/vpiano.ui" line="318"/>
         <source>Edit the current keyboard layout</source>
         <translation>Geçerli klavye düzenini düzenle</translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="322"/>
+        <location filename="../src/vpiano.ui" line="323"/>
         <source>&amp;Contents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="325"/>
+        <location filename="../src/vpiano.ui" line="326"/>
         <source>Open the index of the help document</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="330"/>
+        <location filename="../src/vpiano.ui" line="331"/>
         <source>VMPK &amp;Web site</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="333"/>
+        <location filename="../src/vpiano.ui" line="334"/>
         <source>Open the VMPK web site address using a web browser</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.ui" line="338"/>
+        <location filename="../src/vpiano.ui" line="339"/>
         <source>&amp;Import SoundFont...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/vpiano.cpp" line="1228"/>
+        <location filename="../src/vpiano.cpp" line="1364"/>
         <source>No help file found</source>
         <translation type="unfinished"></translation>
     </message>
